@@ -103,7 +103,7 @@ if   ( -e './gapi.json' ) { say "auth file exists" }
 else                      { croak( 'I only work if gapi.json is here' ); }
 ;    ## prolly better to fail on setup ?
 my $gapi_agent        = WebService::GoogleAPI::Client->new( debug => $DEBUG, gapi_json => './gapi.json' );
-my $aref_token_emails = $gapi_agent->auth_storage->storage->get_token_emails_from_storage;
+my $aref_token_emails = $gapi_agent->auth_storage->get_token_emails_from_storage;
 my $user              = $aref_token_emails->[0];                                                             ## default to the first user
 $gapi_agent->user( $user );
 
